/************************************************************************
 *                                                                      *
 * File:        my_radpr.h		                                *
 *                                                                      *
 * Author(s):   T. Frivold, D.Beyer.  Rooftop Communications.           *
 *                                                                      *
 * Description: File containing private definitions and prototypes      *
 * 		for implementation of example, skeletal			*
 * 		radio device driver.					*
 *                                                                      *
 ************************************************************************/
#ifndef _MY_RADPR_H_
#define _MY_RADPR_H_

/*
 * MyRadio's private device data structure
 */
typedef struct _radioDevData
{
    void         * protoDev;     /* the protocol's handle              */
    DevSigFp       sigReport;    /* callback to report signals         */

    /* radio variables */
    byte           name[128];
    uint32         freq[6];	 /* 6-channel radio      	       */
    uint32	   txPower;	 /* (channels share xmt power setting) */
    int32  	   burstCnt;
    /* ... */
  
} RadioDevData;

typedef void (*IntHandlerFp)(RadioDevData * dev, int32 intNum, 
			     void * data,        int32 len );

/*
 * Hardware/radio specific values
 */
enum
{
    interruptXmtPkt	   = 0x05,
    interruptRcvPkt	   = 0x4E,

    interruptRcvCarrierOn  = 0xF5,
    interruptRcvCarrierOff = 0xF6,
};

/*
 * Hardware/radio/implementation specific support functions
 */

/* Globally enable/disable hardware interrupts */
void		_EnableInterrupts(void);
void		_DisableInterrupts(void);

/* Enable/disable specific hardware/radio interrupts */
void		_InterruptEnable(uint32 intNum);
void		_InterruptDisable(uint32 intNum);

/* Register a hardware interrupt handler */
void		_RegisterInteruptHandler(IntHandlerFp, void * dev
					 /* other args.. */);

/* Self explanator functions */
void		 _TurnOnTransmitter(void);
void		 _TurnOffTransmitter(void);
uint32		 _TransmitterOff(void);
uint32		 _XmtQEmpty(void);

/* Start transmitting a packet immediately */
void		 _XmtPkt(MyRadioPktInfo *pktInfo);

/* Enqueue a packet for transmission */
void		 _XmtQEnqueue(MyRadioPktInfo *pktInfo);

/* Dequeue the next packet for transmission */
MyRadioPktInfo	*_XmtQDequeue(void);

/* Enqueue an empty packet descriptor to be filled upon packet reception */
void		 _RcvQEnqueue(MyRadioPktInfo *pktInfo);

/* Get/Put a device owned MyRadioPktInfo structure from/into internal pool */
MyRadioPktInfo	*_PktInfoPoolGet(void); 
void		 _PktInfoPoolPut(MyRadioPktInfo *pktInfo); 

#endif /* _MY_RADPR_H_ */

